@@ -10,26 +10,17 @@
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
+#ifndef __PACKET_RTP_H__
+#define __PACKET_RTP_H__
+
 #include "epan/packet.h"
 #include "ws_symbol_export.h"
 
 #include "packet-btavdtp.h"
-
+#include "packet-sdp.h"
 
 #define RTP_MEDIA_AUDIO 1
 #define RTP_MEDIA_VIDEO 2
@@ -43,7 +34,9 @@ struct _rtp_info {
 	unsigned int  info_payload_type;
 	unsigned int  info_padding_count;
 	guint16       info_seq_num;
+	guint32       info_extended_seq_num;
 	guint32       info_timestamp;
+	guint64       info_extended_timestamp;
 	guint32       info_sync_src;
 	guint         info_data_len;       /* length of raw rtp data as reported */
 	gboolean      info_all_data_present; /* FALSE if data is cut off */
@@ -55,7 +48,7 @@ struct _rtp_info {
 	const gchar   *info_payload_type_str;
 	gint          info_payload_rate;
 	gboolean      info_is_ed137;
-	const gchar   *info_ed137_info;
+	const gchar   *info_ed137_info;    /* pointer to static string, no freeing is required */
 	/*
 	* info_data: pointer to raw rtp data = header + payload incl. padding.
 	* That should be safe because the "epan_dissect_t" constructed for the packet
@@ -67,16 +60,19 @@ struct _rtp_info {
 };
 
 /* definitions for SRTP dissection */
+/* https://www.iana.org/assignments/srtp-protection/srtp-protection.xhtml */
 
 /* Encryption algorithms */
 #define SRTP_ENC_ALG_NOT_SET	0	/* Data not available/empty record */
 #define SRTP_ENC_ALG_NULL		1	/* non-encrypted SRTP payload - may still be authenticated */
 #define SRTP_ENC_ALG_AES_CM		2	/* SRTP default algorithm */
 #define SRTP_ENC_ALG_AES_F8		3
+#define SRTP_ENC_ALG_AES_GCM            4       /* RFC 7714 */
 
 /* Authentication algorithms */
 #define SRTP_AUTH_ALG_NONE			0	/* no auth tag in SRTP/RTP payload */
 #define SRTP_AUTH_ALG_HMAC_SHA1		1	/* SRTP default algorithm */
+#define SRTP_AUTH_ALG_GMAC		2	/* RFC 7714 */
 
 
 #if 0	/* these are only needed once the dissector include the crypto functions to decrypt and/or authenticate */
@@ -142,15 +138,19 @@ void rtp_dyn_payload_insert(rtp_dyn_payload_t *rtp_dyn_payload,
 /* Replaces the given payload type key in the hash table, with the encoding name and sample rate.
    This makes copies of the encoding name, scoped to the life of the capture file or sooner if
    rtp_dyn_payload_free is called. The replaced encoding name is free'd immediately. */
+/* Not used anymore
 WS_DLL_PUBLIC
 void rtp_dyn_payload_replace(rtp_dyn_payload_t *rtp_dyn_payload,
 							const guint pt,
 							const gchar* encoding_name,
 							const int sample_rate);
+*/
 
 /* removes the given payload type */
+/* Not used anymore
 WS_DLL_PUBLIC
 gboolean rtp_dyn_payload_remove(rtp_dyn_payload_t *rtp_dyn_payload, const guint pt);
+*/
 
 /* retrieves the encoding name for the given payload type; the string returned is only valid
    until the entry is replaced, removed, or the hash table is destroyed, so duplicate it if
@@ -176,25 +176,26 @@ void rtp_dyn_payload_free(rtp_dyn_payload_t *rtp_dyn_payload);
 void rtp_dump_dyn_payload(rtp_dyn_payload_t *rtp_dyn_payload);
 #endif
 
-/* Info to save in RTP conversation / packet-info */
-#define MAX_RTP_SETUP_METHOD_SIZE 7
+/** Info to save in RTP conversation / packet-info */
+#define MAX_RTP_SETUP_METHOD_SIZE 11
 struct _rtp_conversation_info
 {
-	gchar   method[MAX_RTP_SETUP_METHOD_SIZE + 1];
-	guint32 frame_number;			/* the frame where this conversation is started */
-	guint32 media_types;
-	rtp_dyn_payload_t *rtp_dyn_payload;	/* the dynamic RTP payload info - see comments above */
+    gchar   method[MAX_RTP_SETUP_METHOD_SIZE + 1];
+    guint32 frame_number;                           /**> the frame where this conversation is started */
+    guint32 media_types;
+    rtp_dyn_payload_t *rtp_dyn_payload;             /**> the dynamic RTP payload info - see comments above */
 
-	guint32 extended_seqno;			/* the sequence number, extended to a 32-bit
-									 * int to guarantee it increasing monotonically
-									 */
-
-	struct _rtp_private_conv_info *rtp_conv_info; /* conversation info private
-	                                               * to the rtp dissector
-												   */
-	struct srtp_info *srtp_info;    /* SRTP context */
-	bta2dp_codec_info_t *bta2dp_info;
-	btvdp_codec_info_t *btvdp_info;
+    guint32 extended_seqno;                         /**> the sequence number, extended to a 32-bit
+                                                     * int to guarantee it increasing monotonically
+                                                     */
+    guint64 extended_timestamp;                     /**> timestamp extended to 64-bit */
+    struct _rtp_private_conv_info *rtp_conv_info;   /**> conversation info private
+                                                     * to the rtp dissector
+                                                     */
+    struct srtp_info *srtp_info;                    /* SRTP context */
+    bta2dp_codec_info_t *bta2dp_info;
+    btvdp_codec_info_t *btvdp_info;
+    wmem_array_t *rtp_sdp_setup_info_list;           /**> List with data from all SDP occurencies for this steram holding a call ID)*/
 };
 
 /* Add an RTP conversation with the given details */
@@ -218,10 +219,19 @@ void srtp_add_address(packet_info *pinfo,
                      guint32 setup_frame_number,
                      guint32 media_types,
                      rtp_dyn_payload_t *rtp_dyn_payload,
-                     struct srtp_info *srtp_info);
+                     struct srtp_info *srtp_info,
+                     sdp_setup_info_t *setup_info);
 
 /* Add an Bluetooth conversation with the given details */
 void
 bluetooth_add_address(packet_info *pinfo, address *addr, guint32 stream_number,
          const gchar *setup_method, guint32 setup_frame_number,
          guint32 media_types, void *data);
+
+/* Dissect the header only, without side effects */
+WS_DLL_PUBLIC
+gint dissect_rtp_shim_header(tvbuff_t *tvb, gint start,
+                             packet_info *pinfo, proto_tree *tree,
+                             struct _rtp_info *rtp_info);
+
+#endif /*__PACKET_RTP_H__*/
